%define modname endpointconfig2

Summary: Issabel Endpoint Configurator Module
Name: issabel-endpointconfig2
Version: 4.0.0
Release: 5
License: GPL
Group:   Applications/System
Source0: issabel-%{modname}-%{version}.tar.gz
BuildRoot: %{_tmppath}/%{name}-%{version}-root
BuildArch: noarch
Requires: issabelPBX >= 2.8.1-12
Requires: issabel-framework >= 4.0.0-1
Requires: issabel-agenda >= 4.0.0-1
Requires: pyst2-Asterisk
Requires: python-eventlet
Requires: python-tempita
Requires: pyOpenSSL
Requires: python-daemon
Requires: MySQL-python
Requires: python-cjson
Requires: php-simplepie
Requires: python-paramiko >= 1.7.6-2
Requires: nmap
Requires(pre): tftp-server
Conflicts: elastix-pbx <= 2.4.0-15

Obsoletes: elastix-endpointconfig2

%description
The Issabel Endpoint Configurator is a complete rewrite and reimplementation of
the elastix-pbx module known as the Endpoint Configurator. This rewrite
addresses several known design flaws in the old Endpoint Configurator and should
eventually be integrated as the new standard configurator in issabel-pbx.

User-visible features:
- Supports assignment of multiple accounts to a single endpoint.
- Automatic model detection implemented for most supported manufacturers.
- Improved user interface written with Ember.js.
- Network parameters can be updated onscreen in addition to being uploaded.
- Endpoint network scan is cancellable.
- The configuration of every endpoint is executed in parallel, considerably
  shortening the potential wait until all endpoints are configured.
- A log of the actual endpoint configuration can be displayed for diagnostics.
- Supports two additional download formats in addition to the download format of
  the old endpoint configurator - required for multiple account support.
- Custom properties can be assigned to the endpoint and per account, until GUI
  support is properly added.
- Can be installed alongside the old endpoint configurator.
- For supported phones, the module provides an HTTP resource to serve remote
  services, such as a phonebook browser, for better integration with Issabel.

For developers:
- The architecture of the module is plugin-friendly. Each vendor implementation
  (written in Python) has been completely encapsulated and no vendor-specific
  logic remains in the module core itself. To add a new vendor, it is enough to
  write a new implementation class in Python, add new templates if necessary,
  and add database records for MACs. Patching of the core is no longer required.
- Foundation for replacing the standard configurator dialog with a
  vendor-specific one (not yet used).

%prep
%setup -n %{name}-%{version}

%install
rm -rf $RPM_BUILD_ROOT

# Files provided by all Issabel modules
mkdir -p                        $RPM_BUILD_ROOT/var/www/html/
mv modules/                     $RPM_BUILD_ROOT/var/www/html/

# Additional (module-specific) files that can be handled by RPM
mkdir -p $RPM_BUILD_ROOT/etc/
mv setup/etc/httpd/ $RPM_BUILD_ROOT/etc/

mv setup/usr/ $RPM_BUILD_ROOT/
mkdir -p $RPM_BUILD_ROOT/usr/local/share/issabel/endpoint-classes/tpl

rm -rf setup/build/

# ** /tftpboot path ** #
# ** files tftpboot for endpoints configurator ** #
mkdir -p $RPM_BUILD_ROOT/tftpboot
unzip setup/tftpboot/P0S3-08-8-00.zip  -d     $RPM_BUILD_ROOT/tftpboot/
rm setup/tftpboot/P0S3-08-8-00.zip
mv setup/tftpboot/*                           $RPM_BUILD_ROOT/tftpboot/
rmdir setup/tftpboot

# The following folder should contain all the data that is required by the installer,
# that cannot be handled by RPM.
mkdir -p    $RPM_BUILD_ROOT/usr/share/issabel/module_installer/%{name}-%{version}-%{release}/
mv setup/   $RPM_BUILD_ROOT/usr/share/issabel/module_installer/%{name}-%{version}-%{release}/
mv menu.xml $RPM_BUILD_ROOT/usr/share/issabel/module_installer/%{name}-%{version}-%{release}/

%pre
mkdir -p /usr/share/issabel/module_installer/%{name}-%{version}-%{release}/
touch /usr/share/issabel/module_installer/%{name}-%{version}-%{release}/preversion_%{modname}.info
if [ $1 -eq 2 ]; then
    rpm -q --queryformat='%{VERSION}-%{RELEASE}' %{name} > /usr/share/issabel/module_installer/%{name}-%{version}-%{release}/preversion_%{modname}.info
fi


%post
pathModule="/usr/share/issabel/module_installer/%{name}-%{version}-%{release}"

# Run installer script to fix up ACLs and add module to Elastix menus.
issabel-menumerge /usr/share/issabel/module_installer/%{name}-%{version}-%{release}/menu.xml

pathSQLiteDB="/var/www/db"
mkdir -p $pathSQLiteDB
preversion=`cat $pathModule/preversion_%{modname}.info`

if [ $1 -eq 1 ]; then #install
  # The installer database
    issabel-dbprocess "install" "$pathModule/setup/db"

  # Restart apache to disable HTTPS redirect on phonesrv script
  /sbin/service httpd restart
elif [ $1 -eq 2 ]; then #update
    issabel-dbprocess "update"  "$pathModule/setup/db" "$preversion"
fi
rm -f $pathModule/preversion_%{modname}.info

# Remove old endpointconfig2 menu item
issabel-menuremove endpointconfig2

# Prepare tftpboot for use by module
chmod 777 /tftpboot/
cat /usr/share/issabel/module_installer/%{name}-%{version}-%{release}/setup/etc/xinetd.d/tftp > /etc/xinetd.d/tftp

%clean
rm -rf $RPM_BUILD_ROOT

%preun
pathModule="/usr/share/issabel/module_installer/%{name}-%{version}-%{release}"
if [ $1 -eq 0 ] ; then # Validation for desinstall this rpm
  echo "Delete endpoint configurator menus"
  issabel-menuremove endpoint_configurator

  echo "Dump and delete %{name} databases"
  issabel-dbprocess "delete" "$pathModule/setup/db"
fi


%files
%defattr(-, root, root)
%{_localstatedir}/www/html/*
/usr/share/issabel/module_installer/*
/usr/share/issabel/endpoint-classes
/usr/local/share/issabel/endpoint-classes
/tftpboot/*
%defattr(644, root, root)
/etc/httpd/conf.d/issabel-endpointconfig.conf
%defattr(755, root, root)
/usr/bin/*
/usr/share/issabel/privileged/*

%changelog
* Thu May 20 2021 Nicolas Gudino
- (8f93a59) Modify class __construct to please php 7 (HEAD, origin/master, master)

* Tue Apr 6 2021 Nicolas Gudino
- (81e09e6) Add github workflow for rpm building

* Fri Mar 12 2021 Nicolas Gudino
- (570ee49) Fix spacing/indentation

* Thu Mar 11 2021 Nicolas Gudino
- (c46d178) Rename to server_port

* Thu Mar 11 2021 Nicolas Gudino
- (bebae1c) Optimize conditions

* Thu Mar 11 2021 Nicolas Gudino
- (22600c4) Use server port on Yealink templates

* Thu Mar 11 2021 Nicolas Gudino
- (4cec05c) Use server port on Cisco templates

* Thu Mar 11 2021 Nicolas Gudino
- (70eaf3c) Use server port on Polycom templates

* Thu Mar 11 2021 Nicolas Gudino
- (ff2fcd2) Fix fanvil to use new port variables

* Thu Mar 11 2021 Nicolas Gudino
- (7a67ffd) Update Fanvil templates for using configured server ports instead of hardcoding 5060

* Thu Mar 11 2021 Nicolas Gudino
- (491bb49) Support for different server ports on Grandstream provisioning

* Thu Mar 11 2021 Nicolas Gudino
- (501958c) Read server port from config tables instead of hardcoding 5060. Needed for provisioning both SIP and PJSIP accounts

* Thu Mar 11 2021 Nicolas Gudino
- (4db860b) Check if ip of pjsip is in endpointlist

* Tue Mar 9 2021 Nicolas Gudino
- (115997b) Preserve account.tech as pjsip because we will need to differentiate with sip on other functions

* Tue Mar 9 2021 Nicolas Gudino
- (8b13e74) Return true from reboot via http. Fix indenting

* Tue Mar 9 2021 Nicolas Gudino
- (4883f49) Add initial pjsip support

* Tue Mar 9 2021 Nicolás
- (787918e) Use pyst2 instead of py-Asterisk to support Asterisk 16

* Tue Mar 9 2021 Nicolás
- (bfa2370) Fix on grandstream reboot not working the first time because opener was not defined

* Fri Mar 5 2021 Nicolas Gudino
- (043bf94) Bump to release 4

* Fri Mar 5 2021 Nicolas Gudino
- (73c497a) Add support for Fanvil X1

* Fri Mar 5 2021 Nicolas Gudino
- (2a7c330) Add support vlan nic names from ucr micro in server ip discovery

* Sat Nov 30 2019 Nicolas Gudino
- (2816654) Add missing farsi translation file

* Wed Jul 4 2018 Nicolas Gudino
- (4a6ef71) Bump to release 3

* Wed Jul 4 2018 Nicolas
- (c4abd6a) Merge pull request #3 from venturinog/master

* Wed Jul 4 2018 root
- (7a1fb4a) Add support for Grandstream GXP1620, GXP 1760, GXP2160, GXV3240

* Sun Mar 11 2018 root
- (536f122) Add Fanvil Models: X6 - X4 - i20S - H5 Tested on firmwares: 1.2.4(X6) - 2.3.2.4600(X4) - 2.1.1.2898(i20S) - 2.0.2.2818(H5)

* Tue Nov 7 2017 Nicolas Gudino
- (83b44b8) Bump to release 2

* Fri Sep 22 2017 Nicolas Gudino
- (5e1ddf6) Fix single sql bind parameter (thx dwong_007 and kikigak2)

* Wed Sep 13 2017 Nicolas Gudino
- (04eb715) Merge branch 'master' of https://github.com/IssabelFoundation/endpointconfig2

* Wed Sep 13 2017 Nicolas
- (117e257) Merge pull request #2 from markmarco16/master

* Thu Jul 6 2017 Nicolas Gudino
- (728d4b8) No update on release, fix spec only

* Sat Jul 1 2017 Nicolas Gudino
- (86abbae) Update to RPM release 2

* Tue Jun 27 2017 Nicolas Gudino
- (3c4b156) Remove proper menu on uninstall

* Tue Jun 27 2017 Nicolas Gudino
- (11f3acf) Fix typo on module name

* Mon Jun 26 2017 Marco A. Da Silva A
- (92b2845) Fix Dependency Resolution Error

* Tue Jun 20 2017 Nicolas Gudino
- (4daf915) Put endpoint under PBX menu

* Fri Jun 16 2017 Nicolas Gudino
- (8408292) Set endpoint configurator parent to System menu

* Sun Jun 11 2017 Nicolas Gudino
- (d9035cd) Rebranding

* Sun Jun 11 2017 Nicolas Gudino
- (a751132) Rebranding

* Sun Jun 11 2017 Nicolas Gudino
- (24b7726) Rebranding

* Sun Jun 11 2017 Nicolas Gudino
- (73734cd) Upudate attribution comments leaving original copyright and GPL license in place

* Sun Jun 11 2017 Nicolas Gudino
- (93dae3b) Upudate attribution comments leaving original copyright and GPL license in place

* Sun Jun 11 2017 Nicolas Gudino
- (8924a12) Upudate attribution comments leaving original copyright and GPL license in place

* Sat Jun 10 2017 Nicolas Gudino
- (bed5f49) Rebranding

* Sat Jun 10 2017 Nicolas Gudino
- (d0ee509) Rebranding

* Fri Jun 9 2017 Nicolas Gudino
- (139ff6d) Rebranding

* Wed May 31 2017 Nicolas Gudino
- (c07db42) first commit

